%global service cyborg

Summary:        OpenStack Accelerator as a Service
Name:           openstack-%{service}
Version:        6.0.0
Release:        2%{?dist}
License:        Apache-2.0
Group:          Applications/System
URL:            https://launchpad.net/cyborg
Source0:        https://tarballs.opendev.org/openstack/cyborg/%{name}-%{version}.tar.gz
Source1:        %{name}-api.service
Source2:        %{name}-conductor.service
Source3:        %{name}-agent.service

BuildRequires:  python3-sqlalchemy python3-WSME python3-alembic python3-eventlet python3-jsonpatch
BuildRequires:  python3-oslo-concurrency python3-oslo-config python3-oslo-context python3-oslo-db
BuildRequires:  python3-oslo-i18n python3-oslo-log python3-oslo-messaging python3-oslo-policy
BuildRequires:  python3-oslo-service python3-oslo-utils python3-oslo-versionedobjects
BuildRequires:  python3-pbr python3-pecan python3-psutil python3-stevedore python3-keystonemiddleware
BuildRequires:  systemd
BuildRequires:  fdupes
Requires:       %{name}-api = %{version}-%{release}
Requires:       %{name}-conductor = %{version}-%{release}
Requires:       %{name}-agent = %{version}-%{release}
Requires(post): systemd
Requires(postun): systemd
Requires(pre):  shadow-utils
Requires(preun): systemd

BuildArch:      noarch

%description
Cyborg (previously known as Nomad) is an OpenStack project that aims to
provide a general purpose management framework for acceleration
resources (i.e. various types of accelerators such as GPU, FPGA, ASIC,
NP, SoCs, NVMe/NOF SSDs, ODP, DPDK/SPDK and so on).

%package        api
Summary:        Cyborg API service
Requires:       %{name}-common = %{version}-%{release}

%description    api
Cyborg API service

%package        conductor
Summary:        Cyborg conductor service
Requires:       %{name}-common = %{version}-%{release}

%description    conductor
Cyborg conductor service

%package        agent
Summary:        Cyborg agent service
Requires:       %{name}-common = %{version}-%{release}

%description    agent
Cyborg agent service

%package        common
Summary:        Cyborg common files
Requires:       python3-%{service} = %{version}-%{release}

%description    common
Cyborg common files

%package -n     python3-%{service}
Summary:        Cyborg Python library
Requires:       python3-sqlalchemy python3-WSME python3-alembic python3-eventlet python3-jsonpatch
Requires:       python3-oslo-concurrency python3-oslo-config python3-oslo-context python3-oslo-db
Requires:       python3-oslo-i18n python3-oslo-log python3-oslo-messaging python3-oslo-policy
Requires:       python3-oslo-service python3-oslo-utils python3-oslo-versionedobjects
Requires:       python3-pbr python3-pecan python3-psutil python3-stevedore python3-keystonemiddleware

%description -n python3-%{service}
Cyborg (previously known as Nomad) is an OpenStack project that aims to
provide a general purpose management framework for acceleration
resources (i.e. various types of accelerators such as GPU, FPGA, ASIC,
NP, SoCs, NVMe/NOF SSDs, ODP, DPDK/SPDK and so on).

This package contains the Cyborg python libraries.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%{py3_build}

PYTHONPATH=. oslo-config-generator --config-file tools/config/%{service}-config-generator.conf \
    --output-file etc/cyborg/cyborg.conf.sample
PYTHONPATH=. oslopolicy-sample-generator --config-file tools/config/%{service}-policy-generator.conf \
    --output-file etc/cyborg/policy.json.sample

%install
%{py3_install}
install -d -m 755 %{buildroot}%{_localstatedir}/log/cyborg
install -d -m 755 %{buildroot}%{_sysconfdir}/cyborg

mv %{buildroot}%{_prefix}%{_sysconfdir}/cyborg/*  %{buildroot}%{_sysconfdir}/cyborg/
install -p -D -m 640 etc/cyborg/cyborg.conf.sample %{buildroot}%{_sysconfdir}/cyborg/cyborg.conf
install -p -D -m 640 etc/cyborg/policy.yaml %{buildroot}%{_sysconfdir}/cyborg/policy.yaml

install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}/%{name}-api.service
install -p -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}-conductor.service
install -p -D -m 644 %{SOURCE3} %{buildroot}%{_unitdir}/%{name}-agent.service

%fdupes %{buildroot}%{python3_sitelib}

%pre common
getent group %{service} >/dev/null || groupadd -r %{service}
if ! getent passwd %{service} >/dev/null; then
  useradd -r -g %{service} -G %{service} -d %{_localstatedir}/lib/%{service} -s /sbin/nologin -c "OpenStack %{service} Daemons" %{service}
fi

%post api
%systemd_post %{name}-api.service
%post conductor
%systemd_post %{name}-conductor.service
%post agent
%systemd_post %{name}-agent.service

%preun api
%systemd_preun %{name}-api.service
%preun conductor
%systemd_preun %{name}-conductor.service
%preun agent
%systemd_preun %{name}-agent.service

%postun api
%systemd_postun_with_restart %{name}-api.service
%postun conductor
%systemd_postun_with_restart %{name}-conductor.service
%postun agent
%systemd_postun_with_restart %{name}-agent.service

%files
%license LICENSE
%doc README.rst

%files api
%{_bindir}/%{service}-api
%{_bindir}/%{service}-dbsync
%{_bindir}/%{service}-status
%{_bindir}/%{service}-wsgi-api
%config(noreplace) %attr(0640, root, cyborg) %{_sysconfdir}/cyborg/api-paste.ini
%config(noreplace) %attr(0640, root, cyborg) %{_sysconfdir}/cyborg/policy.yaml
%{_unitdir}/%{name}-api.service

%files conductor
%{_bindir}/%{service}-conductor
%{_unitdir}/%{name}-conductor.service

%files agent
%{_bindir}/%{service}-agent
%{_unitdir}/%{name}-agent.service

%files common
%dir %attr(0750, root, cyborg) %{_sysconfdir}/cyborg/
%config(noreplace) %attr(0640, root, cyborg) %{_sysconfdir}/cyborg/cyborg.conf
%dir %attr(0750, cyborg, cyborg) %{_localstatedir}/log/cyborg

%files -n python3-%{service}
%license LICENSE
%doc README.rst
%{python3_sitelib}/cyborg/
%{python3_sitelib}/openstack_cyborg*.egg-info

%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 6.0.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Tue Apr 18 2023 kianli <kianli@tencent.com> - 6.0.0-1
- initial build
